@@ -15,16 +15,17 @@ from pypodo.args import compute_args
 from pypodo.print import (
     printwarning,
     printlinetodo,
+    listalerttags,
+    test_date,
 )
 
 
-
 def listtask(openfile=open):
     """
     Print the todofile with filters or not
     """
     empty = True
-    headers = ["index","task","tags"]
+    headers = ["index", "task", "tags"]
     data = []
     with openfile(todofilefromconfig(), "r") as todofile:
         for line in todofile.readlines():
@@ -40,7 +41,7 @@ def listtask(openfile=open):
                         line.rstrip("\n"),
                     ):
                         display = False
-            if compute_args().exclude:                       
+            if compute_args().exclude:
                 for tagtoexclude in compute_args().exclude:
                     # regex to search tags "#toto " or "#toto" at the end of the line
                     if re.findall(
@@ -49,7 +50,19 @@ def listtask(openfile=open):
                         + REGEX_SPACE_OR_ENDLINE,
                         line.rstrip("\n"),
                     ):
-                        display = False                        
+                        display = False
+            if compute_args().warning:
+                isalert = False
+                for part in line.split():
+                    if (
+                        part.startswith("#")
+                        and part in listalerttags()
+                        or test_date(part[1:]) == "alert"
+                        or test_date(part[1:]) == "warning"
+                    ):
+                        isalert = True
+                if isalert == False:
+                    display = False
             if display:
                 data.append(printlinetodo(line))
                 empty = False
@@ -62,8 +75,15 @@ def listtask(openfile=open):
         if compute_args().condensate:
             table = columnar(data, no_borders=True, wrap_max=0)
         else:
-            if (read_config_boolean("FONCTIONAL", "condensate", "False")== "True"):
+            if (
+                read_config_boolean(
+                    "FONCTIONAL", "condensate", "False"
+                )
+                == "True"
+            ):
                 table = columnar(data, no_borders=True, wrap_max=0)
-            else:    
-                table = columnar(data, headers, no_borders=False, wrap_max=0)            
-        print(table) 
+            else:
+                table = columnar(
+                    data, headers, no_borders=False, wrap_max=0
+                )
+        print(table)
